==> dart_6.9.2.orig.tar.xz: dart-6.9.2/dart/dynamics/CompositeNode.hpp <==
/*
 * Copyright (c) 2011-2019, The DART development contributors
 * All rights reserved.
 *
 * The list of contributors can be found at:
 *   https://github.com/dartsim/dart/blob/master/LICENSE
 *
 * This file is provided under the following "BSD-style" License:
 *   Redistribution and use in source and binary forms, with or
 *   without modification, are permitted provided that the following
 *   conditions are met:
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 *   CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 *   INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 *   MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *   DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 *   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 *   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 *   AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *   POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef DART_DYNAMICS_COMPOSITENODE_HPP_
#define DART_DYNAMICS_COMPOSITENODE_HPP_

#include "dart/common/Composite.hpp"
#include "dart/dynamics/Node.hpp"

namespace dart {
namespace dynamics {

//==============================================================================
template <class Base>
class CompositeStateNode : public Base
{
public:

  using State = Node::MakeState<common::Composite::State>;

  /// Forwarding constructor
  template <typename... Args>
  CompositeStateNode(Args&&... args)
    : Base(std::forward<Args>(args)...)
  {
    // Do nothing
  }

  // Documentation inherited from Node
  void setNodeState(const Node::State& otherState) override final;

  // Documentation inherited from Node
  std::unique_ptr<Node::State> getNodeState() const override final;

  // Documentation inherited from Node
  void copyNodeStateTo(
      std::unique_ptr<Node::State>& outputState) const override final;
};

//==============================================================================
template <class Base>
class CompositePropertiesNode : public Base
{
public:

  using Properties = Node::MakeProperties<common::Composite::Properties>;

  /// Forwarding constructor
  template <typename... Args>
  CompositePropertiesNode(Args&&... args)
    : Base(std::forward<Args>(args)...)
  {
    // Do nothing
  }

  // Documentation inherited from Node
  void setNodeProperties(
      const Node::Properties& otherProperties) override final;

  // Documentation inherited from Node
  std::unique_ptr<Node::Properties> getNodeProperties() const override final;

  // Documentation inherited from Node
  void copyNodePropertiesTo(
      std::unique_ptr<Node::Properties>& outputProperties) const override final;
};

//==============================================================================
template <class Base>
class CompositeNode : public CompositePropertiesNode<CompositeStateNode<Base> >
{
public:

  /// Forwarding constructor
  template <typename... Args>
  CompositeNode(Args&&... args)
    : CompositePropertiesNode<CompositeStateNode<Base>>(
        std::forward<Args>(args)...)
  {
    // Do nothing
  }

};

} // namespace dynamics
} // namespace dart

#include "dart/dynamics/detail/CompositeNode.hpp"

#endif // DART_DYNAMICS_COMPOSITENODE_HPP_

==> dart_6.12.1+dfsg4.orig.tar.xz: dart-6.12.1/dart/dynamics/CompositeNode.hpp <==
/*
 * Copyright (c) 2011-2021, The DART development contributors
 * All rights reserved.
 *
 * The list of contributors can be found at:
 *   https://github.com/dartsim/dart/blob/master/LICENSE
 *
 * This file is provided under the following "BSD-style" License:
 *   Redistribution and use in source and binary forms, with or
 *   without modification, are permitted provided that the following
 *   conditions are met:
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 *   CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 *   INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 *   MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *   DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
 *   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 *   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 *   AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *   LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *   ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *   POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef DART_DYNAMICS_COMPOSITENODE_HPP_
#define DART_DYNAMICS_COMPOSITENODE_HPP_

#include "dart/common/Composite.hpp"
#include "dart/dynamics/Node.hpp"

namespace dart {
namespace dynamics {

//==============================================================================
template <class Base>
class CompositeStateNode : public Base
{
public:
  using State = Node::MakeState<common::Composite::State>;

  /// Forwarding constructor
  template <typename... Args>
  CompositeStateNode(Args&&... args) : Base(std::forward<Args>(args)...)
  {
    // Do nothing
  }

  // Documentation inherited from Node
  void setNodeState(const Node::State& otherState) override final;

  // Documentation inherited from Node
  std::unique_ptr<Node::State> getNodeState() const override final;

  // Documentation inherited from Node
  void copyNodeStateTo(
      std::unique_ptr<Node::State>& outputState) const override final;
};

//==============================================================================
template <class Base>
class CompositePropertiesNode : public Base
{
public:
  using Properties = Node::MakeProperties<common::Composite::Properties>;

  /// Forwarding constructor
  template <typename... Args>
  CompositePropertiesNode(Args&&... args) : Base(std::forward<Args>(args)...)
  {
    // Do nothing
  }

  // Documentation inherited from Node
  void setNodeProperties(
      const Node::Properties& otherProperties) override final;

  // Documentation inherited from Node
  std::unique_ptr<Node::Properties> getNodeProperties() const override final;

  // Documentation inherited from Node
  void copyNodePropertiesTo(
      std::unique_ptr<Node::Properties>& outputProperties) const override final;
};

//==============================================================================
template <class Base>
class CompositeNode : public CompositePropertiesNode<CompositeStateNode<Base>>
{
public:
  /// Forwarding constructor
  template <typename... Args>
  CompositeNode(Args&&... args)
    : CompositePropertiesNode<CompositeStateNode<Base>>(
        std::forward<Args>(args)...)
  {
    // Do nothing
  }
};

} // namespace dynamics
} // namespace dart

#include "dart/dynamics/detail/CompositeNode.hpp"

#endif // DART_DYNAMICS_COMPOSITENODE_HPP_
